@@ -45,12 +45,6 @@
 
 /* === M A C R O S ========================================================= */
 
-// uncomment define SINGLE_THREADED to use a single thread, and hopefully get more stability (dooglus) 
-// changed to be default if using windows (Nov 2009 pixelgeek) - see app.h
-#ifdef SINGLE_THREADED
-#  define single_threaded()	App::single_threaded
-#endif
-
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
