@@ -31,6 +31,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <gtkmm/label.h>
 #include <ETL/stringf>
 #include <gtkmm/celleditable.h>
@@ -49,7 +51,9 @@
 
 #include "cellrenderer_gradient.h"
 #include "cellrenderer_value.h"
+
 #include <synfig/valuenodes/valuenode_bone.h>
+#include <synfig/transformation.h>
 
 #include "widgets/widget_gradient.h"
 #include "dialogs/dialog_gradient.h"
@@ -58,7 +62,7 @@
 
 #include <gdkmm/general.h>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
