@@ -29,15 +29,14 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "docks/dock_curves.h"
 #include "app.h"
 
 #include <gtkmm/scrolledwindow.h>
 #include <cassert>
 #include "instance.h"
-#include <sigc++/signal.h>
-#include <sigc++/hide.h>
-#include <sigc++/slot.h>
 #include "canvasview.h"
 #include "trees/layerparamtreestore.h"
 #include "workarea.h"
@@ -46,7 +45,7 @@
 #include <gtkmm/scrollbar.h>
 #include "widgets/widget_timeslider.h"
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -204,7 +203,7 @@ Dock_Curves::on_update_header_height( int header_height)
 {
 	// FIXME very bad hack (timetrack dock also contains this)
 	//! Adapt the border size "according" to different windows manager rendering
-#ifdef WIN32
+#ifdef _WIN32
 	header_height-=2;
 #elif defined(__APPLE__)
 	header_height+=6;
