@@ -31,21 +31,20 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "docks/dock_timetrack.h"
 #include "app.h"
 
 #include <gtkmm/scrolledwindow.h>
 #include <cassert>
 #include "instance.h"
-#include <sigc++/signal.h>
-#include <sigc++/hide.h>
-#include <sigc++/slot.h>
 #include "canvasview.h"
 #include "trees/layerparamtreestore.h"
 #include "workarea.h"
 #include "widgets/widget_timeslider.h"
 #include "widgets/widget_keyframe_list.h"
-#include "general.h"
+#include <gui/localization.h>
 #include "trees/layertree.h"
 #include <synfig/timepointcollect.h>
 
