@@ -28,6 +28,8 @@
 
 /* === H E A D E R S ======================================================= */
 
+#include <vector>
+
 #include <gtkmm/dialog.h>
 #include <gtkmm/tooltip.h>
 #include <gtkmm/table.h>
@@ -35,7 +37,7 @@
 #include <gtkmm/adjustment.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/checkbutton.h>
-#include <gtkmm/optionmenu.h>
+#include <gtkmm/comboboxtext.h>
 
 #include <synfig/string.h>
 #include <synfig/targetparam.h>
@@ -45,6 +47,8 @@
 
 #include "renddesc.h"
 
+#include <dialogs/dialog_targetparam.h>
+
 /* === M A C R O S ========================================================= */
 
 /* === T Y P E D E F S ===================================================== */
@@ -62,19 +66,19 @@ class RenderSettings : public Gtk::Dialog
 
 	Gtk::Entry entry_filename;
 
-	Gtk::Adjustment adjustment_quality;
+	Glib::RefPtr<Gtk::Adjustment> adjustment_quality;
 	Gtk::SpinButton entry_quality;
 
-	Gtk::Adjustment adjustment_antialias;
+	Glib::RefPtr<Gtk::Adjustment> adjustment_antialias;
 	Gtk::SpinButton entry_antialias;
 
 	Gtk::CheckButton toggle_single_frame;
 	Gtk::CheckButton toggle_extract_alpha;
 
-	Gtk::OptionMenu optionmenu_target;
-	Gtk::Menu *menu_target;
+	Gtk::ComboBoxText comboboxtext_target;
 	Gtk::Button *tparam_button;
 
+	std::vector<synfig::String> target_names;
 	synfig::String target_name;
 	synfig::String calculated_target_name;
 	std::vector< std::pair<synfig::TargetAlphaMode,synfig::String> > render_passes;
@@ -85,13 +89,18 @@ class RenderSettings : public Gtk::Dialog
 
 	synfig::TargetParam tparam;
 
+	static std::map<synfig::String, Dialog_TargetParam *> dialog_book;
+
 public:
 	RenderSettings(Gtk::Window& parent,etl::handle<synfigapp::CanvasInterface> canvas_interface);
 	~RenderSettings();
 	void set_entry_filename();
 
-private:
+	//Use to add new param dialog.
+	static void register_dialog(synfig::String target_name, Dialog_TargetParam * dialog) 
+	{dialog_book[target_name] = dialog;}
 
+private:
 	void on_rend_desc_changed();
 	void on_single_frame_toggle();
 	void on_choose_pressed();
@@ -99,6 +108,7 @@ private:
 	void on_cancel_pressed();
 	void on_targetparam_pressed();
 	void submit_next_render_pass();
+	void on_comboboxtext_target_changed();
 	void on_finished();
 }; // END of class RenderSettings
 
