@@ -31,6 +31,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <synfig/valuenodes/valuenode_dynamiclist.h>
 
 #include "state_bline.h"
@@ -51,7 +53,7 @@
 #include <synfig/transform.h>
 #include <synfigapp/main.h>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #include <gtkmm/separatormenuitem.h>
 #include <gtkmm/imagemenuitem.h>
@@ -496,7 +498,7 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	depth(-1),
 	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	opacity_hscl(0.0f, 1.01f, 0.01f),
+	opacity_hscl(0.0f, 1.0125f, 0.0125f),
 	button_make(_("Make")),
 	button_clear(_("Clear"))
 {
