@@ -30,6 +30,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/grid.h>
@@ -37,6 +39,7 @@
 #include <glibmm/timeval.h>
 #include <giomm.h>
 
+#include <synfig/canvasfilenaming.h>
 #include <synfig/layers/layer_switch.h>
 
 #include "state_brush.h"
@@ -61,7 +64,7 @@
 
 #include "ducktransform_matrix.h"
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -133,8 +136,6 @@ private:
 
 	Gtk::Menu menu;
 
-	std::set<String> paths;
-
 	Glib::TimeVal time;
 	etl::handle<synfigapp::Action::LayerPaint> action;
 	TransformStack transform_stack;
@@ -448,23 +449,25 @@ StateBrush_Context::load_settings()
 	try
 	{
 		synfig::ChangeLocale change_locale(LC_NUMERIC, "C");
-		
+
 		String value;
-		/*if(settings.get_value("brush.path_count",value))
+		bool bvalue(settings.get_value("brush.path_count",value));
+		int count = atoi(value.c_str());
+		if(bvalue && count>0)
 		{
-			paths.clear();
+			App::brushes_path.clear();
 			int count = atoi(value.c_str());
 			for(int i = 0; i < count; ++i)
 				if(settings.get_value(strprintf("brush.path_%d", i),value))
-					paths.insert(value);
+					App::brushes_path.insert(value);
 		}
 		else
-		{*/
-			if (App::brushes_path=="")
-				paths.insert(App::get_base_path()+ETL_DIRECTORY_SEPARATOR+"share"+ETL_DIRECTORY_SEPARATOR+"synfig"+ETL_DIRECTORY_SEPARATOR+"brushes");
+		{
+			if (App::brushes_path.empty())
+				App::brushes_path.insert(App::get_base_path()+ETL_DIRECTORY_SEPARATOR+"share"+ETL_DIRECTORY_SEPARATOR+"synfig"+ETL_DIRECTORY_SEPARATOR+"brushes");
 			else
-				paths.insert(App::brushes_path);
-		//}
+				App::brushes_path.insert(*(App::brushes_path.begin()));
+		}
 		refresh_tool_options();
 
 		if (settings.get_value("brush.selected_brush_filename",value))
@@ -487,9 +490,9 @@ StateBrush_Context::save_settings()
 	{
 		synfig::ChangeLocale change_locale(LC_NUMERIC, "C");
 
-		settings.set_value("brush.path_count", strprintf("%d", (int)paths.size()));
+		settings.set_value("brush.path_count", strprintf("%d", (int)App::brushes_path.size()));
 		int j = 0;
-		for(std::set<String>::const_iterator i = paths.begin(); i != paths.end(); ++i)
+		for(std::set<String>::const_iterator i = App::brushes_path.begin(); i != App::brushes_path.end(); ++i)
 			settings.set_value(strprintf("brush.path_%d", j++), *i);
 
 		settings.set_value("brush.selected_brush_filename", selected_brush_config.filename);
@@ -614,7 +617,7 @@ StateBrush_Context::refresh_tool_options()
 	// load brushes files definition
 	// scan directories
 	std::set<String> files;
-	for(std::set<String>::const_iterator i = paths.begin(); i != paths.end(); ++i)
+	for(std::set<String>::const_iterator i = App::brushes_path.begin(); i != App::brushes_path.end(); ++i)
 		scan_directory(*i, 1, files);
 
 	// run through brush definition and assign a button
@@ -770,27 +773,22 @@ StateBrush_Context::event_mouse_down_handler(const Smach::event& x)
 
 				if (selected_layer->get_param_list().count("filename") != 0)
 				{
-					// TODO: "images" and "container:" literals
-					get_canvas_interface()
-						->get_instance()
-						->get_file_system()
-						->directory_create("#images");
-
 					// generate name based on description
 					String description, filename, filename_param;
 					get_canvas_interface()
 						->get_instance()
 						->generate_new_name(
 								layer,
-								NULL,
-								get_canvas_interface()->get_instance()->get_file_system(),
+								get_canvas(),
+								get_canvas()->get_file_system(),
 								description,
 								filename,
 								filename_param );
 
+					// create and save surface
 					get_canvas_interface()
 						->get_instance()
-						->save_surface(layer->surface, filename);
+						->save_surface(layer->get_surface(), filename);
 
 					selected_layer->set_param("filename", filename_param);
 					selected_layer->set_description(description);
@@ -888,8 +886,8 @@ StateBrush_Context::draw_to(Vector pos, Real pressure)
 	Point p = transform_stack.unperform( pos );
 	Point tl = action->stroke.get_layer()->get_param("tl").get(Point());
 	Point br = action->stroke.get_layer()->get_param("br").get(Point());
-	int w = action->stroke.get_layer()->surface.get_w();
-	int h = action->stroke.get_layer()->surface.get_h();
+	int w = action->stroke.get_layer()->rendering_surface ? action->stroke.get_layer()->rendering_surface->get_width() : 0;
+	int h = action->stroke.get_layer()->rendering_surface ? action->stroke.get_layer()->rendering_surface->get_height() : 0;
 
 	action->stroke.add_point_and_apply(
 		synfigapp::Action::LayerPaint::PaintPoint(
