@@ -30,6 +30,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 #include <synfig/valuenodes/valuenode_bline.h>
@@ -50,7 +52,7 @@
 #include "widgets/widget_distance.h"
 #include <synfigapp/main.h>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -523,7 +525,7 @@ StateCircle_Context::StateCircle_Context(CanvasView* canvas_view):
 	duckmatic_push(get_work_area()),
 	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	opacity_hscl(0.0f, 1.01f, 0.01f),
+	opacity_hscl(0.0f, 1.0125f, 0.0125f),
 	number_of_bline_points_adj(Gtk::Adjustment::create(0, 2, 120, 1, 1)),
 	number_of_bline_points_spin(number_of_bline_points_adj, 1, 0),
 	bline_point_angle_offset_adj(Gtk::Adjustment::create(0, -360, 360, 0.1, 1)),
