@@ -31,6 +31,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 #include <synfig/valuenodes/valuenode_bline.h>
@@ -51,7 +53,7 @@
 #include "widgets/widget_distance.h"
 #include <synfigapp/main.h>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -474,7 +476,7 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 	duckmatic_push(get_work_area()),
 	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	opacity_hscl(0.0f, 1.01f, 0.01f)
+	opacity_hscl(0.0f, 1.0125f, 0.0125f)
 {
 	egress_on_selection_change=true;
 
