@@ -31,6 +31,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 #include <synfig/valuenodes/valuenode_bline.h>
@@ -51,7 +53,7 @@
 #include "widgets/widget_distance.h"
 #include <synfigapp/main.h>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -583,7 +585,7 @@ StateStar_Context::StateStar_Context(CanvasView* canvas_view):
 	duckmatic_push(get_work_area()),
 	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	opacity_hscl(0.0f, 1.01f, 0.01f),
+	opacity_hscl(0.0f, 1.0125f, 0.0125f),
 	number_of_points_adj(Gtk::Adjustment::create(0, 2, 120, 1, 1)),
 	number_of_points_spin(number_of_points_adj,1,0),
 	radius_ratio_adj(Gtk::Adjustment::create(0, -10, 10, 0.01, 0.1)),
