@@ -27,8 +27,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <sigc++/signal.h>
-#include <sigc++/slot.h>
+#include <sigc++/sigc++.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/adjustment.h>
 #include <synfig/distance.h>
