@@ -33,11 +33,11 @@
 
 #include <synfig/general.h>
 
-#include "widgets/widget_timeslider.h"
-
+#include <cmath>
 #include <ETL/misc>
 
-#include <cmath>
+#include "widgets/widget_timeslider.h"
+#include "app.h"
 
 #include <gui/localization.h>
 
@@ -59,240 +59,10 @@ const double zoomoutfactor = 1/zoominfactor;
 
 /* === P R O C E D U R E S ================================================= */
 
-Gdk::RGBA get_interp_color(synfig::Interpolation x)
-{
-	switch(x)
-	{
-	case INTERPOLATION_TCB:
-		return Gdk::RGBA("#73d216");
-	case INTERPOLATION_LINEAR:
-		return Gdk::RGBA("#edd400");
-	case INTERPOLATION_CONSTANT:
-		return Gdk::RGBA("#cc0000");
-	case INTERPOLATION_HALT:
-		return Gdk::RGBA("#3465a4");
-	case INTERPOLATION_MANUAL:
-		return Gdk::RGBA("#75507b");
-	case INTERPOLATION_CLAMPED:
-		return Gdk::RGBA("#c17d11");
-	case INTERPOLATION_UNDEFINED:
-	default:
-		break;
-	}
-	return Gdk::RGBA("#555753");
-}
-
-static Gdk::RGBA
-color_darken(Gdk::RGBA x, float amount)
-{
-	x.set_red(x.get_red() * amount);
-	x.set_green(x.get_green() * amount);
-	x.set_blue(x.get_blue() * amount);
-	return x;
-}
-
-void
-studio::render_time_point_to_window(
-	const Cairo::RefPtr<Cairo::Context> &cr,
-	const Gdk::Rectangle& area,
-	const synfig::TimePoint &tp,
-	bool selected
-)
-{
-	const Gdk::RGBA black("#2e3436"); // it's black, trust me
-
-	if(selected)
-		cr->set_line_width(2.0);
-	else
-		cr->set_line_width(1.0);
-
-	Gdk::RGBA color;
-
-/*-	BEFORE ------------------------------------- */
-
-	color=get_interp_color(tp.get_before());
-	color=color_darken(color,1.0f);
-	if(selected)color=color_darken(color,1.3f);
-	cr->set_source_rgb(color.get_red(),color.get_green(),color.get_blue());
-
-	switch(tp.get_before())
-	{
-	case INTERPOLATION_TCB:
-		cr->save();
-		cr->translate(area.get_x(), area.get_y());
-		cr->scale(area.get_width(), area.get_height());
-		cr->arc(0.5, 0.5, 0.5, 90*M_PI/180.0, 270*M_PI/180.0);
-		cr->fill_preserve();
-		cr->restore();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		break;
-
-	case INTERPOLATION_HALT:
-		cr->save();
-		cr->translate(area.get_x(), area.get_y());
-		cr->scale(area.get_width(), area.get_height()*2);
-		cr->move_to(0.5, 0.5);
-		cr->arc(0.5, 0.5, 0.5, 180*M_PI/180.0, 270*M_PI/180.0);
-		cr->fill();
-		cr->arc(0.5, 0.5, 0.5, 180*M_PI/180.0, 270*M_PI/180.0);
-		cr->restore();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->move_to(area.get_x(),area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->stroke();
-
-		break;
-
-	case INTERPOLATION_LINEAR:
-		cr->save();
-		cr->move_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x(),area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_CONSTANT:
-		cr->save();
-		cr->move_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width()/4,area.get_y());
-		cr->line_to(area.get_x()+area.get_width()/4,area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x(),area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x(),area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_CLAMPED:
-		cr->save();
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x(),area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_UNDEFINED: default:
-		cr->save();
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width()/3,area.get_y());
-		cr->line_to(area.get_x(),area.get_y()+area.get_height()/3);
-		cr->line_to(area.get_x(),area.get_y()+area.get_height()-area.get_height()/3);
-		cr->line_to(area.get_x()+area.get_width()/3,area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-	}
-
-/*-	AFTER -------------------------------------- */
-
-	color=get_interp_color(tp.get_after());
-	color=color_darken(color,0.8f);
-	if(selected)color=color_darken(color,1.3f);
-	cr->set_source_rgb(color.get_red(),color.get_green(),color.get_blue());
-
-	switch(tp.get_after())
-	{
-	case INTERPOLATION_TCB:
-		cr->save();
-		cr->translate(area.get_x(), area.get_y());
-		cr->scale(area.get_width(), area.get_height());
-		cr->arc(0.5, 0.5, 0.5, -90*M_PI/180.0, 90*M_PI/180.0);
-		cr->fill_preserve();
-		cr->restore();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		break;
-
-	case INTERPOLATION_HALT:
-		cr->save();
-		cr->translate(area.get_x(), area.get_y());
-		cr->scale(area.get_width(), area.get_height()*2);
-		cr->move_to(0.5, 0.0);
-		cr->arc(0.5, 0.0, 0.5, 0*M_PI/180.0, 90*M_PI/180.0);
-		cr->fill();
-		cr->arc(0.5, 0.0, 0.5, 0*M_PI / 180.0, 90*M_PI / 180.0);
-		cr->restore();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->move_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y());
-		cr->stroke();
-
-		break;
-
-	case INTERPOLATION_LINEAR:
-		cr->save();
-		cr->move_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_CONSTANT:
-		cr->save();
-		cr->move_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x()+area.get_width()-area.get_width()/4,area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x()+area.get_width()-area.get_width()/4,area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_CLAMPED:
-		cr->save();
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y()+area.get_height()/2);
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-
-	case INTERPOLATION_UNDEFINED: default:
-		cr->save();
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y());
-		cr->line_to(area.get_x()+area.get_width()-area.get_width()/3,area.get_y());
-		cr->line_to(area.get_x()+area.get_width(),area.get_y()+area.get_height()/3);
-		cr->line_to(area.get_x()+area.get_width(),area.get_y()+area.get_height()-area.get_height()/3);
-		cr->line_to(area.get_x()+area.get_width()-area.get_width()/3,area.get_y()+area.get_height());
-		cr->line_to(area.get_x()+area.get_width()/2,area.get_y()+area.get_height());
-		cr->fill_preserve();
-		cr->set_source_rgb(black.get_red(),black.get_green(),black.get_blue());
-		cr->stroke();
-		cr->restore();
-		break;
-	}
-
-}
-
 /* === M E T H O D S ======================================================= */
 
 /* === E N T R Y P O I N T ================================================= */
+
 double defaultfps = 24;
 const int fullheight = 20;
 
