@@ -33,11 +33,13 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "renderer_dragbox.h"
 #include "workarea.h"
 #include <ETL/misc>
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
@@ -200,7 +202,7 @@ Renderer_Dragbox::render_vfunc(
 		cr->set_antialias(Cairo::ANTIALIAS_NONE);
 
 		cr->set_line_width(1.0);
-		cr->set_source_rgb(0,0,0);
+		cr->set_source_rgb(GDK_COLOR_TO_RGB(DRAGBOX_COLOR_OUTLINE));
 		std::valarray<double> dashes(2);
 		dashes[0]=5.0;
 		dashes[1]=5.0;
