@@ -29,10 +29,12 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "workarearenderer.h"
 #include "workarea.h"
 
-#include "general.h"
+#include <gui/localization.h>
 
 #endif
 
