@@ -2,7 +2,7 @@
 /*!	\file colorset.h
 **	\brief Template File
 **
-**	$Id: colorset.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,23 +46,42 @@ class ColorSet :
 {
 private:
 
-	ValueDesc value_desc;
+	std::list<ValueDesc> value_desc_list;
 	synfig::Color color;
 	synfig::Time time;
+	bool use_outline_color;
 
 public:
 
-	ColorSet();
+	ColorSet(bool use_outline_color);
 
 	static ParamVocab get_param_vocab();
 	static bool is_candidate(const ParamList &x);
 
 	virtual bool set_param(const synfig::String& name, const Param &);
-	virtual bool is_ready()const;
+	virtual bool is_ready() const;
 
 	virtual void prepare();
+};
+
+class ColorSetFromOC : public ColorSet
+{
+public:
+
+	ColorSetFromOC() : ColorSet(true) {}
 
 	ACTION_MODULE_EXT
+
+};
+
+class ColorSetFromFC : public ColorSet
+{
+public:
+
+	ColorSetFromFC() : ColorSet(false) {}
+
+	ACTION_MODULE_EXT
+
 };
 
 }; // END of namespace action
