@@ -29,6 +29,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "keyframeduplicate.h"
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenodes/valuenode_dynamiclist.h>
@@ -36,7 +38,7 @@
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #endif
 
