@@ -29,6 +29,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "layermakebline.h"
 #include "layeradd.h"
 #include "layermove.h"
@@ -36,7 +38,7 @@
 #include <synfig/context.h>
 #include <synfigapp/canvasinterface.h>
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #endif
 
@@ -163,7 +165,7 @@ Action::LayerMakeBLine::prepare_make_bline(const synfig::String &bline_layer_nam
 
 	// Apply some defaults
 	new_layer->set_canvas(subcanvas);
-	get_canvas_interface()->apply_layer_param_defaults(new_layer);
+	get_canvas_interface()->layer_set_defaults(new_layer);
 
 	// Set depth
 	{
