@@ -30,12 +30,14 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "layerzdepthrangeset.h"
 #include "layeradd.h"
 #include "layerremove.h"
 #include <synfigapp/canvasinterface.h>
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #include <synfig/layers/layer_group.h>
 
@@ -129,7 +131,7 @@ Action::LayerZDepthRangeSet::set_param(const synfig::String& name, const Action:
 		if(layer)
 		{
 			// Expand position and depth to include the given layer
-			float layer_z_depth=layer->get_true_z_depth();
+			float layer_z_depth=layer->get_true_z_depth(Time(0));
 			if(z_position > layer_z_depth)
 				z_position=layer_z_depth;
 			if(z_position + z_depth <= layer_z_depth)
