@@ -30,6 +30,8 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "valuenodeadd.h"
 
 #include "canvasadd.h"
@@ -42,7 +44,7 @@
 #include <synfig/valuenodes/valuenode_const.h>
 #include <synfig/context.h>
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #endif
 
@@ -255,7 +257,7 @@ Action::ValueDescExport::prepare()
 		Canvas::Handle prev_canvas = canvas;
 
 		// clone canvas (all code that clones a canvas has this comment)
-		if (canvas) canvas=canvas->clone(GUID(), true);
+		if (canvas) canvas=canvas->clone(synfig::GUID(), true);
 
 		if (external)
 		{
