@@ -30,11 +30,13 @@
 #	include <config.h>
 #endif
 
+#include <synfig/general.h>
+
 #include "valuenodedynamiclistinsertsmart.h"
 #include "valuenodedynamiclistinsert.h"
 #include <synfigapp/canvasinterface.h>
 
-#include <synfigapp/general.h>
+#include <synfigapp/localization.h>
 
 #endif
 
@@ -229,6 +231,7 @@ Action::ValueNodeDynamicListInsertSmart::prepare()
 			action->set_param("canvas_interface",get_canvas_interface());
 			action->set_param("time",time);
 			action->set_param("origin",origin);
+			if (!keep_shape) action->set_param("force_link_radius",true);
 			action->set_param("value_desc",ValueDesc(value_node,index));
 
 			if(!action->is_ready())
@@ -354,6 +357,7 @@ Action::ValueNodeDynamicListInsertSmart::prepare()
 		action->set_param("canvas_interface",get_canvas_interface());
 		action->set_param("time",time);
 		action->set_param("origin",origin);
+		if (!keep_shape) action->set_param("force_link_radius",true);
 		action->set_param("value_desc",ValueDesc(value_node,index));
 
 		if(!action->is_ready())
